# presenter

MVP模型中的V层，负责 view 的绘制、更新、删除等视图层操作，由 Presenter 层回调 并 由 Activity、Fragment、View、ViewGroup 等具体视图类实现。

#### 一个简单的模型如下

```java

package cn.motoon.view;

public interface IContactsView {
    void update(List<Contacts> contactsList);
}

```

> 以上为联系人更新View接口

```java

package cn.motoon.presenter;

public class ContactsPresenterImpl {
    public ContactsPresenterImpl(IContactsView view) {
         mView = view;
    }

    public void get() {
         // get contacts list from Contacts Model

         mView.update(contactsList);

         // code
    }
}

```

> 以上为 Contacts 在 presenter 层的实现，引用并回调 IContactsView 实现业务与视图上的分离

```java

package cn.motoon;

public class ContactsFragment extents BaseFragment implements INameView {
     // code

     public void onCreate() {
          // code

          new ContactsPresenterImpl(this).get();

          // code
     }

     public void update(List<Contacts> contactsList) {
         // update contacts list
     }

     // code
}

```

> 以上为 view 接口的具体实现类 并 由其触发业务的执行
